﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Hotline.Share.Tools;
public static class ListExtensions
{
    public static bool IsNullOrEmpty<T>(this List<T> value)
    {
        return value == null || value.Count == 0;
    }

    public static bool NotNullOrEmpty<T>(this List<T> value)
    {
        return value != null && value.Count != 0;
    }

    public static bool NotNullOrEmpty<T>(this IList<T> value)
    {
        return value != null && value.Count != 0;
    }

    public static bool IsNullOrEmpty<T>(this IList<T> value)
    {
        return value == null || value.Count == 0;
    }

    public static bool NotNullOrEmpty<T>(this IReadOnlyList<T> value)
    {
        return value != null && value.Count != 0;
    }

    public static void AddSumLine<T>(this IList<T> list, string fieldName)
    {
        var type = typeof(T);
        var properties = type.GetProperties();
        var sumLine = Activator.CreateInstance<T>();
        foreach (var property in properties)
        {
            if (property.Name == fieldName)
            {
                property.SetValue(sumLine, "合计");
            }
            else if (property.PropertyType == typeof(int))
            {
                property.SetValue(sumLine, list.Sum(m => (int)property.GetValue(m)));
            }
            else if (property.PropertyType == typeof(decimal))
            {
                property.SetValue(sumLine, list.Sum(m => (decimal)property.GetValue(m)));
            }
            else if (property.PropertyType == typeof(double?))
            {
                property.SetValue(sumLine, list.Sum(m => (double)property.GetValue(m)));
            }
        }
        list.Add(sumLine);
    }
}
